@@ -27,6 +27,7 @@ import java.util.List;
 import java.util.Set;
 
 import org.apache.maven.lifecycle.LifecycleExecutor;
+import org.apache.maven.model.Build;
 import org.apache.maven.model.Plugin;
 import org.apache.maven.plugin.MavenPluginManager;
 import org.apache.maven.plugin.Mojo;
@@ -193,6 +194,23 @@ public class DefaultMavenReportExecutor
             }
         }
 
+        if ( !reports.isEmpty() )
+        {
+            // log reports, either configured or detected
+            StringBuilder buff = new StringBuilder();
+            for ( MavenReportExecution mre : reports )
+            {
+                if ( buff.length() > 0 )
+                {
+                    buff.append( ", " );
+                }
+                buff.append( mre.getGoal() );
+            }
+            logger.info( reports.size() + " report" + ( reports.size() > 1 ? "s" : "" ) + " "
+                + ( hasUserDefinedReports ? "configured" : "detected" ) + " for " + plugin.getArtifactId() + ":"
+                + plugin.getVersion() + ": " + buff );
+        }
+
         return reports;
     }
 
@@ -648,6 +666,7 @@ public class DefaultMavenReportExecutor
      * <li>dependencies</li>
      * </ul>
      * </p>
+     * The plugin could only be present in the dependency management section.
      * 
      * @param mavenReportExecutorRequest
      * @param buildPlugin
@@ -656,7 +675,12 @@ public class DefaultMavenReportExecutor
     private void mergePluginToReportPlugin( MavenReportExecutorRequest mavenReportExecutorRequest, Plugin buildPlugin,
                                             ReportPlugin reportPlugin )
     {
-        Plugin configuredPlugin = find( reportPlugin, mavenReportExecutorRequest.getProject().getBuild().getPlugins() );
+        Build build = mavenReportExecutorRequest.getProject().getBuild();
+        Plugin configuredPlugin = find( reportPlugin, build.getPlugins() );
+        if ( configuredPlugin == null && build.getPluginManagement() != null )
+        {
+            configuredPlugin = find( reportPlugin, build.getPluginManagement().getPlugins() );
+        }
         if ( configuredPlugin != null )
         {
             if ( !configuredPlugin.getDependencies().isEmpty() )
@@ -676,7 +700,7 @@ public class DefaultMavenReportExecutor
 
         private final PluginDescriptor pluginDescriptor;
 
-        public GoalWithConf( ReportPlugin reportPlugin, PluginDescriptor pluginDescriptor, String goal,
+        GoalWithConf( ReportPlugin reportPlugin, PluginDescriptor pluginDescriptor, String goal,
                              PlexusConfiguration configuration )
         {
             this.reportPlugin = reportPlugin;
